@@ -27,7 +27,7 @@ no warnings _disabled_warnings();
 use B::Hooks::AtRuntime 'after_runtime';
 use Import::Into;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub import {
     my ( $class, %args ) = @_;
@@ -125,7 +125,7 @@ MooseX::Extended - Extend Moose with safe defaults and useful features
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -161,7 +161,10 @@ version 0.22
 =head1 DESCRIPTION
 
 This module is B<BETA> code. It's feature-complete for release and has no
-known bugs.
+known bugs. We believe it's ready for production, but make no promises.
+
+This is a quick overview. See L<MooseX::Extended::Manual::Tutorial> for more
+information.
 
 This class attempts to create a safer version of Moose that defaults to
 read-only attributes and is easier to read and write.
@@ -259,49 +262,49 @@ problem. You can exclude the following:
 
 =item * C<StrictConstructor>
 
-    use MooseX::Extended::Role excludes => ['StrictConstructor'];
+    use MooseX::Extended excludes => ['StrictConstructor'];
 
 Excluding this will no longer import C<MooseX::StrictConstructor>.
 
 =item * C<autoclean>
 
-    use MooseX::Extended::Role excludes => ['autoclean'];
+    use MooseX::Extended excludes => ['autoclean'];
 
 Excluding this will no longer import C<namespace::autoclean>.
 
 =item * C<c3>
 
-    use MooseX::Extended::Role excludes => ['c3'];
+    use MooseX::Extended excludes => ['c3'];
 
 Excluding this will no longer apply the C3 mro.
 
 =item * C<carp>
 
-    use MooseX::Extended::Role excludes => ['carp'];
+    use MooseX::Extended excludes => ['carp'];
 
 Excluding this will no longer import C<Carp::croak> and C<Carp::carp>.
 
 =item * C<immutable>
 
-    use MooseX::Extended::Role excludes => ['immutable'];
+    use MooseX::Extended excludes => ['immutable'];
 
 Excluding this will no longer make your class immutable.
 
 =item * C<true>
 
-    use MooseX::Extended::Role excludes => ['true'];
+    use MooseX::Extended excludes => ['true'];
 
 Excluding this will require your module to end in a true value.
 
 =item * C<param>
 
-    use MooseX::Extended::Role excludes => ['param'];
+    use MooseX::Extended excludes => ['param'];
 
 Excluding this will make the C<param> function unavailable.
 
 =item * C<field>
 
-    use MooseX::Extended::Role excludes => ['field'];
+    use MooseX::Extended excludes => ['field'];
 
 Excluding this will make the C<field> function unavailable.
 
